# PYTHON DISK USAGE

Takes a path as an argument and returns it's total disk usage recursively.

## USAGE

```
usage: pdu [-h] [path]

Python Disk Usage Calculator.

positional arguments:
  path        A valid path.

optional arguments:
  -h, --help  show this help message and exit
```
